import QtQuick 1.1
import com.nokia.meego 1.0
import QtWebKit 1.0

Page {
    tools: commonTools
    orientationLock: PageOrientation.LockPortrait

    function escapeStringForJavaScript(str) {
        return str.replace(/\\/g, '\\\\')
                  .replace(/'/g, '\\\'')
                  .replace(/"/g, '\\"')
                  .replace(/\n/g, '\\n')
                  .replace(/\r/g, '\\r');
    }

    WebView {
        id: webView
        anchors.fill: parent
        url: "chat.html"
        settings.javascriptCanAccessClipboard: true
        settings.localStorageDatabaseEnabled: true
        settings.offlineStorageDatabaseEnabled: true
        settings.offlineWebApplicationCacheEnabled: true
        settings.localContentCanAccessRemoteUrls: true
        settings.privateBrowsingEnabled: false

        javaScriptWindowObjects: QtObject {
            WebView.windowObjectName: "native"

            function loadSettingsFromFile() {
                var settingsStr = settingsHandler.loadData();
                return JSON.parse(settingsStr);
            }

            function doChatGptRequest(url, apiKey, data) {
                chatGptHandler.doRequest(url, apiKey, data);
            }
        }

        Connections {
            target: chatGptHandler
            onRequestCompleted: {
                webView.evaluateJavaScript("botResponseCompleted()");
            }
            onPartialResponse: {
                var partialData = webView.evaluateJavaScript("localStorage.getItem('partialData')") || "";
                partialData += response;
                var dataBlocks = partialData.split(/data:/).filter(Boolean);
                var newPartialData = "";
                dataBlocks.forEach(function(block, index) {
                    try {
                        block = block.trim();
                        var jsonResponse = JSON.parse(block);
                        var extractedContent = jsonResponse['choices'][0]['delta']['content'];
                        var escapedContent = escapeStringForJavaScript(extractedContent);
                        webView.evaluateJavaScript("addBotPartialResultContent('" + escapedContent + "')");
                    } catch (error) {
                        if (index === dataBlocks.length - 1) {
                            newPartialData += "data: " + block;
                        } else {
                            console.log("Error parsing JSON:", error);
                        }
                    }
                });

                webView.evaluateJavaScript("localStorage.setItem('partialData', '" + escapeStringForJavaScript(newPartialData) + "');");
            }
            onRequestError: {
                var escapedError = escapeStringForJavaScript(error);
                webView.evaluateJavaScript("addBotError('" + escapedError + "')");
            }
        }
    }
}
